/*
	Funkcie na prstup k vvojovej doske
*/

#ifndef __VYVOJOVADOSKA_H__
#define __VYVOJOVADOSKA_H__

#include <cstdint>

// Paket pre INTERRUPT IN
struct usbapp_interrupt_in_t
{
	uint8_t buttons;
	uint8_t slider;
};

// Tlaidl QTouch
enum usbapp_qtouch_buttons_t
{
	QTouchButton_Valid = 0x1,
	QTouchButton_Up = 0x2,
	QTouchButton_Right = 0x4,
	QTouchButton_Down = 0x8,
	QTouchButton_Left = 0x10
};

// Tlaidl pushbutton (switch)
enum usbapp_pushbuttons_buttons_t
{
	PushButton_Left = 0x20,
	PushButton_Right = 0x40
};

// Nastavenia pre displej
enum usbapp_control_display_options_t
{
	DisplayOption_DisplayOn = 0x1,
	DisplayOption_BacklightOn = 0x2
};

// Max. intenzita podsvietenia LCD
const uint8_t usbapp_control_backlight_max = 32u;

// Max. PWM duty pre LED
const uint8_t usbapp_control_pwm_max = 100u;

// rka obrazovky
const uint32_t usbapp_display_width = 240U;

// Vka obrazovky
const uint32_t usbapp_display_height = 320U;

// Nastavenia LED did
enum usbapp_control_led_options_t
{
	LedOption_Blue = 0x1,
	LedOption_Green = 0x2,
	LedOption_Amber = 0x4
};

// Paket pre SETUP OUT
struct usbapp_control_out_t
{
	uint8_t leds;
	uint8_t pwmLedDuty;
	uint8_t display;
	uint8_t backlight;
	uint16_t displayScroll;
};

// Typ poiadavky pre SETUP OUT
enum usbapp_control_out_types_t
{
	ControlType_Out = 0x1,
	ControlType_In = 0x2
};

// Paket pre SETUP IN
struct usbapp_control_in_t
{
	uint16_t potentiometer;
	uint16_t temperatureDigital;
	float temperature;
};

// Max. hodnota pre prevodnk ADC
const uint16_t usbapp_adc_max_digital = 4095U;

// Hodnota naptia pri max. hodnote prevodnku ADC
const float usbapp_adc_voltage_ref = 5.0f;

// Hodnota naptia senzoru teploty pri max. hodnote prevodnku ADC
const float usbapp_adc_temperature_voltage_ref = 3.3f;

// Nastavenia pre BULK OUT
enum usbapp_bulk_options_t
{
	DrawOption_Bitmap = 0x0,
	DrawOption_Text = 0x80000000,
	DrawOption_TextLine = 0x40000000,
	DrawOption_Clear = 0x20000000,
	DrawOption_ColorMask = 0x00FFFFFF
};

// Paket pre BULK OUT
struct usbapp_bulk_out_t
{
	uint16_t posX;
	uint16_t posY;
	uint16_t width;
	uint16_t height;
	uint32_t options;
};

// Hodnoty, ktor vrti funkcia OpenDevice()
enum EResultOpen
{
	// Otvorenie prebehlo v poriadku
	ResultOpen_OK = 0,
	// Zariadenie nenjden
	ResultOpen_NotFound,
	// Chyba svisiaca s otvorenm intancie na zariadenie
	ResultOpen_ErrorOpen,
	// Nebolo mon zvoli konfigurciu
	ResultOpen_Configuration,
	// Nebolo mon zvoli rozhranie
	ResultOpen_Interface,
	// Nebolo mon zvoli rozhranie
	ResultOpen_AltInterface,
	// In chyba
	ResultOpen_Error
};

// Hodnoty, ktor mu vrti funkcie pracujce so zariadenm
enum EDeviceError
{
	// iadna chyba, opercia prebehla spene
	DeviceError_OK = 0,
	// Nesprvny parameter
	DeviceError_InvalidParameter,
	// Zariadenie nie je otvoren
	DeviceError_NotOpen,
	// Chyba svisiaca s prenosom dajov
	DeviceError_Transfer,
	// Vekos odoslanch/prijatch dt sa nezhoduje s poadovanou vekosou
	DeviceError_InvalidSize
};

//////////////////////////////////////////////
// FUNKCIE

extern "C"
{

// Otvor intanciu zariadenia "Vvojov doska"
__declspec(dllexport) unsigned int OpenDevice();

// Zatvor otvoren intanciu zariadenia
__declspec(dllexport) void CloseDevice();

// Preta hodnoty z prevodnka ADC (potenciometer a teplotu)
__declspec(dllexport) unsigned int ReadADC(usbapp_control_in_t * data);

// Nastav zariadenie (LED a LCD)
__declspec(dllexport) unsigned int SetupDevice(usbapp_control_out_t * data);

// Pok na vstupn paket preruenia (ke sa niekto dotkne tlaidiel na doske)
__declspec(dllexport) unsigned int WaitForInterrupt(usbapp_interrupt_in_t * data);

// Vyist obrazovku jednou farbou
__declspec(dllexport) unsigned int ClearScreen(unsigned int color);

// Vykresl text na displeji
__declspec(dllexport) unsigned int DrawString(usbapp_bulk_out_t * options, const char * text,
	unsigned int textLength);

// Zska adresu, kde je mon vloi bitmapu na vykreslenie
__declspec(dllexport) uint16_t * GetBitmapBuffer();

// Vykresl as obrzku na displej
__declspec(dllexport) unsigned int DrawBitmap(usbapp_bulk_out_t * options);

// Vykresl cel obrzok na displeji
__declspec(dllexport) unsigned int DrawImage(unsigned int x, unsigned int y,
	unsigned int width, unsigned int height, uint16_t * data);

// Skonvertuje 32 bitov bitmapu na 16 bitov
__declspec(dllexport) void Convert32Bitmap(uint32_t * source, uint16_t * destination,
	unsigned int width, unsigned int height);

}
#endif